#!/bin/bash
# change gcc and g++.
# 
# Usage: chgcc -v {296|343|345|346}
#
# Copyright 2004 MIRACLE LINUX CORPORATION
#
# History:
#   21 Apr 2004 first version
#

gcc_ver="unknown"
gplus_ver="unknown"
usage="USAGE: $0 -v {296|343|345|346}"

if [ $# != 2 ]; then
	echo $usage
	exit 1
fi

uid=`/usr/bin/id|awk -F\( '{print $2}'|awk -F\) '{print $1}'`
if [ $uid != "root" ];then
	echo "You must be logged in as root."
	exit 1
fi

while getopts ":v:" opt
do
	case $opt in
	v) 
        targetver=$OPTARG
		if [ $targetver != "296" -a $targetver != "343" -a $targetver != "345" -a $targetver != "346" ]; then
			echo $usage
			exit 1
		fi
		;;
	*)
		echo $usage
		exit 1
	esac
done

if [ -z "$targetver" ]; then
	echo $usage
	exit 1
fi

ch296()
{
	mv /usr/bin/gcc /usr/bin/gcc"$gcc_ver_p"
	mv /usr/bin/g++ /usr/bin/g++"$gplus_ver_p"
	ln -s /usr/bin/gcc296 /usr/bin/gcc
	ln -s /usr/bin/g++296 /usr/bin/g++

	echo ""
	echo "The gcc and g++ were changed to each 2.96."
	echo "When you want to return it, run \"$0 -v $gcc_ver_p\" command."
	echo ""
	echo "mv /usr/bin/gcc /usr/bin/gcc"$gcc_ver_p""
	echo "mv /usr/bin/g++ /usr/bin/g++"$gplus_ver_p""
	echo "ln -s /usr/bin/gcc296 /usr/bin/gcc"
	echo "ln -s /usr/bin/g++296 /usr/bin/g++"
}

ch_org()
{
	if [ -L /usr/bin/gcc ] && [ -L /usr/bin/g++ ]; then
		rm /usr/bin/gcc
		rm /usr/bin/g++
	else
		echo "ERROR: logic error."
		exit 1
	fi
	
	mv /usr/bin/gcc"$targetver" /usr/bin/gcc
	mv /usr/bin/g++"$targetver" /usr/bin/g++
	
	sys_gcc_ver
	echo ""
	echo "The gcc and g++ were changed to each "$gcc_ver"(original version)."
	echo "When you want to change 2.96, run \"$0 -v 296\" command."
	echo ""
	echo "rm /usr/bin/gcc"
	echo "rm /usr/bin/g++"
	echo "mv /usr/bin/gcc"$targetver" /usr/bin/gcc"
	echo "mv /usr/bin/g++"$targetver" /usr/bin/g++"
}

if [ ! -f /usr/bin/gcc ]; then
	echo "/usr/bin/gcc does not exists."
	exit 1
fi
if [ ! -f /usr/bin/g++ ]; then
	echo "/usr/bin/g++ does not exists."
	exit 1
fi

sys_gcc_ver()
{
	gcc_ver_tmp=`/usr/bin/gcc --version`
	echo $gcc_ver_tmp | grep "3.2.3" >/dev/null
	if [ $? = 0 ]; then
		is_script=`file /usr/bin/gcc | cut -d: -f2`
		if [ "$is_script" = " symbolic link to \`/usr/bin/gcc296'" ]; then
			gcc_ver="2.96"
		fi
	fi
	echo $gcc_ver_tmp | grep "3.4.3" >/dev/null
	if [ $? = 0 ]; then
		gcc_ver="3.4.3"
		gcc_ver_p="343"
	fi
	echo $gcc_ver_tmp | grep "3.4.5" >/dev/null
	if [ $? = 0 ]; then
		gcc_ver="3.4.5"
		gcc_ver_p="345"
	fi
	echo $gcc_ver_tmp | grep "3.4.6" >/dev/null
	if [ $? = 0 ]; then
		gcc_ver="3.4.6"
		gcc_ver_p="346"
	fi
}

sys_gplus_ver()
{
	gplus_ver_tmp=`/usr/bin/g++ --version`

	echo $gplus_ver_tmp | grep "3.2.3" >/dev/null
	if [ $? = 0 ]; then
		is_script=`file /usr/bin/g++ | cut -d: -f2`
		if [ "$is_script" = " symbolic link to \`/usr/bin/g++296'" ]; then
			gplus_ver="2.96"
		fi
	fi
	echo $gplus_ver_tmp | grep "3.4.3" >/dev/null
	if [ $? = 0 ]; then
		gplus_ver="3.4.3"
		gplus_ver_p="343"
	fi
	echo $gplus_ver_tmp | grep "3.4.5" >/dev/null
	if [ $? = 0 ]; then
		gplus_ver="3.4.5"
		gplus_ver_p="345"
	fi
	echo $gplus_ver_tmp | grep "3.4.6" >/dev/null
	if [ $? = 0 ]; then
		gplus_ver="3.4.6"
		gplus_ver_p="346"
	fi
}

sys_gcc_ver
sys_gplus_ver

echo "The current gcc version is $gcc_ver."
echo "The current g++ version is $gplus_ver."

if [ "$gcc_ver_p" = "$targetver" ]; then
	echo "It doesn't need to change it."
	exit 1
fi

if [ ! -f /usr/bin/gcc"$targetver" ]; then
	echo "/usr/bin/gcc"$targetver" does not exists."
	exit 1
fi
if [ ! -f /usr/bin/g++"$targetver" ]; then
	echo "/usr/bin/g++"$targetver" does not exists."
	exit 1
fi


if [ $gcc_ver = "unknown" ] || [ $gplus_ver = "unknown" ]; then
	echo "Discovered unknown version."
	exit 1
fi
if [ $gcc_ver != $gplus_ver ]; then
	echo "Mismatch version gcc and g++."
	exit 1
fi


if [ "$targetver" = "296" ] && [ "$gcc_ver" = "3.4.3" -o "$gcc_ver" = "3.4.5" -o "$gcc_ver" = "3.4.6" ]; then
	ch296
elif [ $gcc_ver = "2.96" ] && [ $targetver = "343" -o $targetver = "345" -o $targetver = "346" ]; then
	ch_org
else
	echo "It doesn't need to change it."
fi

exit 0
